# Optifik

Python library to compute a thickness from an interferometric spectrum.

This library replaces [oospectro](https://github.com/sciunto-org/oospectro/).

## Documentation

<https://sciunto-org.github.io/optifik/>

## Installation

The use of pip must be limited to virtualenv


* From PyPI
```
pip install optifik
```

* From tarball
```
pip install /path/to/optifik-0.1.0.tar.gz
```

* From the source code
```
pip install .
```


## For contributors

* Install an editable version
```
pip install -e .
```

* Install dev tools
```
pip install -e ".[dev]"
```

* Run the test suite
```
pytest
```

* Install doc tools
```
pip install -e ".[docs]"
```

* Build the doc
```
sphinx-build -b html docs docs/_build/html
```

## Licence

The source code is released under the GNU General Public License v3.0.
See LICENSE for details.
